//
//  TeamViewController.m
//  VexAPI
//
//  Created by Nick McGuire on 2012-12-07.
//
//

#import "TeamViewController.h"
#import "NMDownloader.h"
#import "Team.h"

@interface TeamViewController ()

@property (strong, nonatomic) NMDownloader *downloader;
@property (strong, nonatomic) NSMutableArray *teams;

@end

@implementation TeamViewController

- (id)initWithStyle:(UITableViewStyle)style
{
    self = [super initWithStyle:style];
    if (self) {
        // Custom initialization
		_downloader = [[NMDownloader alloc] init];
		_teams = [[NSMutableArray alloc] init];
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
	[_downloader getTeams:^(NSURLResponse *response, NSData *data, NSError *err) {
		if (!err) {
			NSError *jsonErr;
			NSMutableArray *arr = [NSJSONSerialization JSONObjectWithData:data options:NSJSONReadingMutableContainers error:&jsonErr];
			
			if (!jsonErr)
			{
				for (int i = 0; i < arr.count; i++)
				{
					Team *team = [[Team alloc] initWithDictionary:[arr objectAtIndex:i]];
					NSLog(@"Team: %@", team.getName);
					[_teams addObject:team];
				}
				
				dispatch_sync(dispatch_get_main_queue(), ^{
					[[self tableView] reloadData];
				});
			} else {
				NSLog(@"jsonErr: %@", jsonErr);
			}
		} else {
			NSLog(@"err: %@", err);
		}
	}];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark - Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return [_teams count];
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"Cell";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
	
	if (cell == nil)
	{
		cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:CellIdentifier];
	}
    
	Team *team = [_teams objectAtIndex:indexPath.row];
	
	cell.textLabel.text = [team getName];
	cell.detailTextLabel.text = [NSString stringWithFormat:@"School ID: %i", [team getSchool]];
	
    return cell;
}

#pragma mark - Table view delegate

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
	[[self tableView] deselectRowAtIndexPath:indexPath animated:YES];
}

@end
